==> haskell-mwc-random-0.14.0.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.14.0.0
id: mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue
key: mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue
license: BSD-3-Clause
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
abi: 13b0a70bc032f17e1af67dfb839e49c8
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource
import-dirs: /usr/lib/ghc-8.4.3/site-local/mwc-random-0.14.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/mwc-random-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/mwc-random-0.14.0.0
hs-libraries: HSmwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue
depends:
    base-4.11.1.0 primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc time-1.8.0.2
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    math-functions-0.3.0.2-4TeUD9HzvwXAMjvZvu2qup
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             math-functions-0.3.0.2-4TeUD9HzvwXAMjvZvu2qup=835d1e98e5d00531fd31c6048fc36b0b
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.14.0.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.14.0.0
id: mwc-random-0.14.0.0-CHYtJffaTqvHIHYnw7lP6P
key: mwc-random-0.14.0.0-CHYtJffaTqvHIHYnw7lP6P
license: BSD-3-Clause
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
abi: 3aef39f8847bb5dad7e9b8c0d6d322af
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource
import-dirs: /usr/lib/ghc-8.6.1/site-local/mwc-random-0.14.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/mwc-random-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/mwc-random-0.14.0.0
hs-libraries: HSmwc-random-0.14.0.0-CHYtJffaTqvHIHYnw7lP6P
depends:
    base-4.12.0.0 math-functions-0.3.0.2-LhI2u4R1Sf7EpQbf7OyAjE
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf time-1.8.0.2
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
